pub struct StatMsgV1 {
pub hd: RecordHeader,
pub ts_recv: u64,
pub ts_ref: u64,
pub price: i64,
pub quantity: i32,
pub sequence: u32,
pub ts_in_delta: i32,
pub stat_type: u16,
pub channel_id: u16,
pub update_action: u8,
pub stat_flags: u8,
/* private fields */
}Expand description
A statistics message. A catchall for various data disseminated by publishers. The
stat_type indicates the statistic contained in the message.
Fields
hd: RecordHeaderThe common header.
ts_recv: u64The capture-server-received timestamp expressed as the number of nanoseconds since the UNIX epoch.
See ts_recv.
ts_ref: u64The reference timestamp of the statistic value expressed as the number of
nanoseconds since the UNIX epoch. Will be UNDEF_TIMESTAMP when
unused.
price: i64The value for price statistics where every 1 unit corresponds to 1e-9, i.e.
1/1,000,000,000 or 0.000000001. Will be UNDEF_PRICE
when unused.
See Prices.
quantity: i32The value for non-price statistics. Will be UNDEF_STAT_QUANTITY
when unused.
sequence: u32The message sequence number assigned at the venue.
ts_in_delta: i32The matching-engine-sending timestamp expressed as the number of nanoseconds before
ts_recv.
See ts_in_delta.
stat_type: u16The type of statistic value contained in the message. Refer to the
StatType enum for possible variants.
channel_id: u16The channel ID assigned by Databento as an incrementing integer starting at zero.
update_action: u8Indicates if the statistic is newly added (1) or deleted (2). (Deleted is only used with some stat types).
stat_flags: u8Additional flags associate with certain stat types.
Implementations
Sourceimpl StatMsg
impl StatMsg
Sourcepub fn ts_recv(&self) -> Option<OffsetDateTime>
pub fn ts_recv(&self) -> Option<OffsetDateTime>
Parses the capture-server-received timestamp into a datetime.
Returns None if ts_recv contains the sentinel for a null timestamp.
Sourcepub fn ts_ref(&self) -> Option<OffsetDateTime>
pub fn ts_ref(&self) -> Option<OffsetDateTime>
Parses the reference timestamp of the statistic value into a datetime.
Returns None if ts_ref contains the sentinel for a null timestamp.
Sourcepub fn price_f64(&self) -> f64
pub fn price_f64(&self) -> f64
Converts the value for price statistics to a floating point.
UNDEF_PRICE will be converted to NaN.
Sourcepub fn ts_in_delta(&self) -> Duration
pub fn ts_in_delta(&self) -> Duration
Parses the difference between ts_recv and the matching-engine-sending timestamp into a duration.
Sourcepub fn update_action(&self) -> Result<StatUpdateAction>
pub fn update_action(&self) -> Result<StatUpdateAction>
Parses the update action into an enum.
Errors
This function returns an error if the update_action field does not
contain a valid StatUpdateAction.