MergeRecordDecoder

Struct MergeRecordDecoder 

pub struct MergeRecordDecoder<D> { /* private fields */ }
Merges the record decoding streams from one or more other decoders, performing a k-merge based on Record::index_ts().

Implementations

Source

impl<D> RecordDecoder<D>
where D: DecodeRecordRef,

pub fn new(decoders: Vec<D>) -> Result<Self>

Creates a new record-stream merging decoder.

Errors

This function returns an error if decoders is empty. It will also return an error if one of the inner decoders returns an error while decoding the first record. A decoder returning Ok(None) does not result in a failure.

pub fn with_hints(decoders: Vec<D>, start_ts_hints: Vec<u64>) -> Result<Self>

Creates a new record-stream merging decoder with a hint for the start time for each decoder. This can assist the merger to avoid reading from a decoder before necessary.

The hint timestamp must be <= raw_index_ts() of the first record in the file. Metadata::start is an example source of for hint.

Errors

This function returns an error if decoders is empty or decoders and start_ts_hints are of different lengths. It will also return an error if one of the inner decoders returns an error while decoding the first record. A decoder returning Ok(None) does not result in a failure.