Struct dbn::encode::csv::Encoder

source ·
pub struct Encoder<W>where
    W: Write,{ /* private fields */ }
Type for encoding files and streams of DBN records in CSV.

Note that encoding Metadata in CSV is not supported.

Implementations

source

impl<W> Encoder<W>where W: Write,

source

pub fn new(writer: W, use_pretty_px: bool, use_pretty_ts: bool) -> Self

Creates a new Encoder that will write to writer. If use_pretty_px is true, price fields will be serialized as a decimal. If pretty_ts is true, timestamp fields will be serialized in a ISO8601 datetime string.