pub enum NoSchemaBehavior {
Skip,
Error,
Broadcast,
}Expand description
How to handle records with an rtype that doesn’t map to a schema such as an
ErrorMsg.
Variants
Skip
Skip records with rtypes that have no schema.
Error
Return an error when encountering an rtype without a schema.
Broadcast
Route records with rtypes that have no schema to all existing encoders.