AsyncEncoder

Struct AsyncEncoder 

pub struct AsyncEncoder<W>
where W: AsyncWriteExt + Unpin,
{ /* private fields */ }
Available on crate feature async only.
Type for encoding files and streams of DBN records in JSON lines.

Implementations

Source

impl<W> Encoder<W>
where W: AsyncWriteExt + Unpin,

pub fn new( writer: W, should_pretty_print: bool, use_pretty_px: bool, use_pretty_ts: bool, ) -> Self

Creates a new instance of Encoder. If should_pretty_print is true, each JSON object will be nicely formatted and indented, instead of the default compact output with no whitespace between key-value pairs.

pub async fn encode_metadata(&mut self, metadata: &Metadata) -> Result<()>

Encodes metadata into JSON.

Errors

This function returns an error if there’s an error writing to writer.

Cancel safety

This method is not cancellation safe. If this method is used in a tokio::select! statement and another branch completes first, then the metadata JSON may have been partially written, but future calls will begin writing the metadata JSON from the beginning.

pub fn get_ref(&self) -> &W

Returns a reference to the underlying writer.

pub fn get_mut(&mut self) -> &mut W

Returns a mutable reference to the underlying writer.