Encoder

Struct Encoder 

pub struct Encoder<W>
where W: Write,
{ /* private fields */ }
Type for encoding files and streams of DBN records in JSON lines.

Implementations

Source

impl<W> Encoder<W>
where W: Write,

pub fn new( writer: W, should_pretty_print: bool, use_pretty_px: bool, use_pretty_ts: bool, ) -> Self

Creates a new instance of Encoder. If should_pretty_print is true, each JSON object will be nicely formatted and indented, instead of the default compact output with no whitespace between key-value pairs.

pub fn builder(writer: W) -> EncoderBuilder<W>

Creates a builder for configuring an Encoder object.

pub fn encode_metadata(&mut self, metadata: &Metadata) -> Result<()>

Encodes metadata into JSON.

Errors

This function returns an error if there’s an error writing to writer.

pub fn get_ref(&self) -> &W

Returns a reference to the underlying writer.

pub fn get_mut(&mut self) -> &mut W

Returns a mutable reference to the underlying writer.