SymbolSplitter

Struct SymbolSplitter 

pub struct SymbolSplitter<E, F, M> { /* private fields */ }
Splits a stream by symbol.

It’s generic over SymbolIndex, allowing it to work with both TsSymbolMap and PitSymbolMap.

Implementations

Source

impl<E, F, M> SymbolSplitter<E, F, M>
where F: Fn(&str, Option<Metadata>) -> Result<E>, M: SymbolIndex,

pub fn new(build_encoder: F, symbol_map: M) -> Self

Creates a new splitter that will split the input stream by symbol, creating a separate sub-encoder for each symbol using build_encoder.

The symbol_map is used to look up the symbol for each record based on the instrument ID (and optionally the timestamp for TsSymbolMap).