ErrorCode

Enum ErrorCode 

#[non_exhaustive]
#[repr(u8)]
pub enum ErrorCode { AuthFailed = 1, ApiKeyDeactivated = 2, ConnectionLimitExceeded = 3, SymbolResolutionFailed = 4, InvalidSubscription = 5, InternalError = 6, SkippedRecordsAfterSlowReading = 7, Unset = 255, }
An error code from the live subscription gateway.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AuthFailed = 1

The authentication step failed.



ApiKeyDeactivated = 2

The user account or API key were deactivated.



ConnectionLimitExceeded = 3

The user has exceeded their open connection limit.



SymbolResolutionFailed = 4

One or more symbols failed to resolve.



InvalidSubscription = 5

There was an issue with a subscription request (other than symbol resolution).



InternalError = 6

An error occurred in the gateway.



SkippedRecordsAfterSlowReading = 7

A slow client was detected and records were skipped by the gateway to allow catching up.



Unset = 255

No error code was specified or this record was upgraded from a version 1 struct where the code field didn’t exist.

Implementations

Source

impl ErrorCode

pub const fn as_str(&self) -> &'static str

Converts the ErrorCode to its str representation.