RType

Enum RType 

#[repr(u8)]
pub enum RType {
Show 23 variants Mbp0 = 0, Mbp1 = 1, Mbp10 = 10, OhlcvDeprecated = 17, Ohlcv1S = 32, Ohlcv1M = 33, Ohlcv1H = 34, Ohlcv1D = 35, OhlcvEod = 36, Status = 18, InstrumentDef = 19, Imbalance = 20, Error = 21, SymbolMapping = 22, System = 23, Statistics = 24, Mbo = 160, Cmbp1 = 177, Cbbo1S = 192, Cbbo1M = 193, Tcbbo = 194, Bbo1S = 195, Bbo1M = 196,
}
A record type, i.e. a sentinel for different types implementing HasRType.

Use in RecordHeader to indicate the type of record, which is useful when working with DBN streams containing multiple record types.

Variants



Mbp0 = 0

Denotes a market-by-price record with a book depth of 0 (used for the Trades schema).



Mbp1 = 1

Denotes a market-by-price record with a book depth of 1 (also used for the Tbbo schema).



Mbp10 = 10

Denotes a market-by-price record with a book depth of 10.



OhlcvDeprecated = 17

👎Deprecated since 0.3.3: Separated into separate rtypes for each OHLCV schema.

Denotes an open, high, low, close, and volume record at an unspecified cadence.



Ohlcv1S = 32

Denotes an open, high, low, close, and volume record at a 1-second cadence.



Ohlcv1M = 33

Denotes an open, high, low, close, and volume record at a 1-minute cadence.



Ohlcv1H = 34

Denotes an open, high, low, close, and volume record at an hourly cadence.



Ohlcv1D = 35

Denotes an open, high, low, close, and volume record at a daily cadence based on the UTC date.



OhlcvEod = 36

Denotes an open, high, low, close, and volume record at a daily cadence based on the end of the trading session.



Status = 18

Denotes an exchange status record.



InstrumentDef = 19

Denotes an instrument definition record.



Imbalance = 20

Denotes an order imbalance record.



Error = 21

Denotes an error from gateway.



SymbolMapping = 22

Denotes a symbol mapping record.



System = 23

Denotes a non-error message from the gateway. Also used for heartbeats.



Statistics = 24

Denotes a statistics record from the publisher (not calculated by Databento).



Mbo = 160

Denotes a market-by-order record.



Cmbp1 = 177

Denotes a consolidated best bid and offer record.



Cbbo1S = 192

Denotes a consolidated best bid and offer record subsampled on a one-second interval.



Cbbo1M = 193

Denotes a consolidated best bid and offer record subsampled on a one-minute interval.



Tcbbo = 194

Denotes a consolidated best bid and offer trade record containing the consolidated BBO before the trade



Bbo1S = 195

Denotes a best bid and offer record subsampled on a one-second interval.



Bbo1M = 196

Denotes a best bid and offer record subsampled on a one-minute interval.

Implementations

Source

impl RType

pub fn try_into_schema(rtype: u8) -> Option<Schema>

Tries to convert the given rtype to a Schema.

Returns None if there’s no corresponding Schema for the given rtype or in the case of OHLCV_DEPRECATED, it doesn’t map to a single Schema.

pub const fn interval(self) -> Option<Duration>

Returns the interval associated with the RType if it’s a subsampled record type, otherwise None.

Source

impl RType

pub const fn as_str(&self) -> &'static str

Converts the RType to its str representation.