SType

Enum SType 

#[repr(u8)]
pub enum SType {
Show 13 variants InstrumentId = 0, RawSymbol = 1, Smart = 2, Continuous = 3, Parent = 4, NasdaqSymbol = 5, CmsSymbol = 6, Isin = 7, UsCode = 8, BbgCompId = 9, BbgCompTicker = 10, Figi = 11, FigiTicker = 12,
}
A symbology type. Refer to the symbology documentation for more information.

Variants



InstrumentId = 0

Symbology using a unique numeric ID.



RawSymbol = 1

Symbology using the original symbols provided by the publisher.



Smart = 2

👎Deprecated since 0.5.0: Smart was split into continuous and parent.

A set of Databento-specific symbologies for referring to groups of symbols.



Continuous = 3

A Databento-specific symbology where one symbol may point to different instruments at different points of time, e.g. to always refer to the front month future.



Parent = 4

A Databento-specific symbology for referring to a group of symbols by one “parent” symbol, e.g. ES.FUT to refer to all ES futures.



NasdaqSymbol = 5

Symbology for US equities using NASDAQ Integrated suffix conventions.



CmsSymbol = 6

Symbology for US equities using CMS suffix conventions.



Isin = 7

Symbology using International Security Identification Numbers (ISIN) - ISO 6166.



UsCode = 8

Symbology using US domestic Committee on Uniform Securities Identification Procedure (CUSIP) codes.



BbgCompId = 9

Symbology using Bloomberg composite global IDs.



BbgCompTicker = 10

Symbology using Bloomberg composite tickers.



Figi = 11

Symbology using Bloomberg FIGI exchange level IDs.



FigiTicker = 12

Symbology using Bloomberg exchange level tickers.

Implementations

Source

impl SType

pub const fn as_str(&self) -> &'static str

Converts the SType to its str representation.