#[repr(u8)]pub enum Side {
Ask = 65,
Bid = 66,
None = 78,
}Expand description
A side of the market. The side of the market for resting orders, or the side of the aggressor for trades.
Variants
Ask = 65
A sell order or sell aggressor in a trade.
Bid = 66
A buy order or a buy aggressor in a trade.
None = 78
No side specified by the original source.