StatusReason

Enum StatusReason 

#[non_exhaustive]
#[repr(u16)]
pub enum StatusReason {
Show 34 variants None = 0, Scheduled = 1, SurveillanceIntervention = 2, MarketEvent = 3, InstrumentActivation = 4, InstrumentExpiration = 5, RecoveryInProcess = 6, Regulatory = 10, Administrative = 11, NonCompliance = 12, FilingsNotCurrent = 13, SecTradingSuspension = 14, NewIssue = 15, IssueAvailable = 16, IssuesReviewed = 17, FilingReqsSatisfied = 18, NewsPending = 30, NewsReleased = 31, NewsAndResumptionTimes = 32, NewsNotForthcoming = 33, OrderImbalance = 40, LuldPause = 50, Operational = 60, AdditionalInformationRequested = 70, MergerEffective = 80, Etf = 90, CorporateAction = 100, NewSecurityOffering = 110, MarketWideHaltLevel1 = 120, MarketWideHaltLevel2 = 121, MarketWideHaltLevel3 = 122, MarketWideHaltCarryover = 123, MarketWideHaltResumption = 124, QuotationNotAvailable = 130,
}
The secondary enum for a StatusMsg update, explains the cause of a halt or other change in action.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 0

No reason is given.



Scheduled = 1

The change in status occurred as scheduled.



SurveillanceIntervention = 2

The instrument stopped due to a market surveillance intervention.



MarketEvent = 3

The status changed due to activity in the market.



InstrumentActivation = 4

The derivative instrument began trading.



InstrumentExpiration = 5

The derivative instrument expired.



RecoveryInProcess = 6

Recovery in progress.



Regulatory = 10

The status change was caused by a regulatory action.



Administrative = 11

The status change was caused by an administrative action.



NonCompliance = 12

The status change was caused by the issuer not being compliance with regulatory requirements.



FilingsNotCurrent = 13

Trading halted because the issuer’s filings are not current.



SecTradingSuspension = 14

Trading halted due to an SEC trading suspension.



NewIssue = 15

The status changed because a new issue is available.



IssueAvailable = 16

The status changed because an issue is available.



IssuesReviewed = 17

The status changed because the issue(s) were reviewed.



FilingReqsSatisfied = 18

The status changed because the filing requirements were satisfied.



NewsPending = 30

Relevant news is pending.



NewsReleased = 31

Relevant news was released.



NewsAndResumptionTimes = 32

The news has been fully disseminated and times are available for the resumption in quoting and trading.



NewsNotForthcoming = 33

The relevant news was not forthcoming.



OrderImbalance = 40

Halted for order imbalance.



LuldPause = 50

The instrument hit limit up or limit down.



Operational = 60

An operational issue occurred with the venue.



AdditionalInformationRequested = 70

The status changed until the exchange receives additional information.



MergerEffective = 80

Trading halted due to merger becoming effective.



Etf = 90

Trading is halted in an ETF due to conditions with the component securities.



CorporateAction = 100

Trading is halted for a corporate action.



NewSecurityOffering = 110

Trading is halted because the instrument is a new offering.



MarketWideHaltLevel1 = 120

Halted due to the market-wide circuit breaker level 1.



MarketWideHaltLevel2 = 121

Halted due to the market-wide circuit breaker level 2.



MarketWideHaltLevel3 = 122

Halted due to the market-wide circuit breaker level 3.



MarketWideHaltCarryover = 123

Halted due to the carryover of a market-wide circuit breaker from the previous trading day.



MarketWideHaltResumption = 124

Resumption due to the end of a market-wide circuit breaker halt.



QuotationNotAvailable = 130

Halted because quotation is not available.