VersionUpgradePolicy

Enum VersionUpgradePolicy 

pub enum VersionUpgradePolicy {
    AsIs,
    UpgradeToV2,
    UpgradeToV3,
}
How to handle decoding DBN data from other versions.

Variants



AsIs

Decode data from all supported versions (less than or equal to DBN_VERSION) as-is.



UpgradeToV2

Decode and convert data from DBN versions prior to version 2 to that version. Attempting to decode data from newer versions will fail.



UpgradeToV3

Decode and convert data from DBN versions prior to version 3 to that version. Attempting to decode data from newer versions (when they’re introduced) will fail.

Implementations

Source

impl VersionUpgradePolicy

pub fn validate_compatibility(self, version: u8) -> Result<()>

Validates a given DBN version is compatible with the upgrade policy.

Errors

This function returns an error if the version and upgrade policy are incompatible.

pub fn output_version(self, input_version: u8) -> u8

Returns the output DBN version given the input version and upgrade policy.