#[non_exhaustive]#[repr(u8)]pub enum InstrumentClass {
Bond = 66,
Call = 67,
Future = 70,
Stock = 75,
MixedSpread = 77,
Put = 80,
FutureSpread = 83,
OptionSpread = 84,
FxSpot = 88,
CommoditySpot = 89,
}Expand description
The class of instrument.
For example usage see Getting options with their underlying.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Bond = 66
A bond.
Call = 67
A call option.
Future = 70
A future.
Stock = 75
A stock.
MixedSpread = 77
A spread composed of multiple instrument classes.
Put = 80
A put option.
FutureSpread = 83
A spread composed of futures.
OptionSpread = 84
A spread composed of options.
FxSpot = 88
A foreign exchange spot.
CommoditySpot = 89
A commodity being traded for immediate delivery.
Implementations
Sourceimpl InstrumentClass
impl InstrumentClass
Sourcepub fn is_option(&self) -> bool
pub fn is_option(&self) -> bool
Returns true if the instrument class is a type of option.
Note: excludes Self::MixedSpread, which may include options.
Sourcepub fn is_future(&self) -> bool
pub fn is_future(&self) -> bool
Returns true if the instrument class is a type of future.
Note: excludes Self::MixedSpread, which may include futures.