#[repr(u8)]pub enum MatchAlgorithm {
Undefined = 32,
Fifo = 70,
Configurable = 75,
ProRata = 67,
FifoLmm = 84,
ThresholdProRata = 79,
FifoTopLmm = 83,
ThresholdProRataLmm = 81,
EurodollarFutures = 89,
TimeProRata = 80,
InstitutionalPrioritization = 86,
}Expand description
The type of matching algorithm used for the instrument at the exchange.
Variants
Undefined = 32
No matching algorithm was specified.
Fifo = 70
First-in-first-out matching.
Configurable = 75
A configurable match algorithm.
ProRata = 67
Trade quantity is allocated to resting orders based on a pro-rata percentage: resting order quantity divided by total quantity.
FifoLmm = 84
Like Self::Fifo but with LMM allocations prior to FIFO allocations.
ThresholdProRata = 79
Like Self::ProRata but includes a configurable allocation to the first order that
improves the market.
FifoTopLmm = 83
Like Self::FifoLmm but includes a configurable allocation to the first order that
improves the market.
ThresholdProRataLmm = 81
Like Self::ThresholdProRata but includes a special priority to LMMs.
EurodollarFutures = 89
Special variant used only for Eurodollar futures on CME.
TimeProRata = 80
Trade quantity is shared between all orders at the best price. Orders with the highest time priority receive a higher matched quantity.
InstitutionalPrioritization = 86
A two-pass FIFO algorithm. The first pass fills the Institutional Group the aggressing order is associated with. The second pass matches orders without an Institutional Group association. See CME documentation.