#[non_exhaustive]#[repr(u8)]pub enum SystemCode {
Heartbeat = 0,
SubscriptionAck = 1,
SlowReaderWarning = 2,
ReplayCompleted = 3,
EndOfInterval = 4,
Unset = 255,
}Expand description
A SystemMsg code indicating the type of message from the live
subscription gateway.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Heartbeat = 0
A message sent in the absence of other records to indicate the connection remains open.
SubscriptionAck = 1
An acknowledgement of a subscription request.
SlowReaderWarning = 2
The gateway has detected this session is falling behind real-time.
ReplayCompleted = 3
Indicates a replay subscription has caught up with real-time data.
EndOfInterval = 4
Signals that all records for interval-based schemas have been published for the given timestamp.
Unset = 255
No system code was specified or this record was upgraded from a version 1 struct where the code field didn’t exist.
Implementations