rtype_method_dispatch

Macro rtype_method_dispatch 

macro_rules! rtype_method_dispatch {
    ($rec_ref:expr, $this:expr, $generic_method:ident $(,$arg:expr)*) => { ... };
}
๐Ÿ‘ŽDeprecated since 0.32.0:

Use the updated rtype_dispatch macro

Specializes a generic method to all record types and dispatches based rtype.

Errors

This macro returns an error if the rtype is not recognized.