Module pretty

Module pretty 

Contains new types for pretty-printing timestamp and prices found in DBN records.

Structs

Px
A new type for formatting the fixed-precision prices used in DBN.
Ts
A new type for formatting nanosecond UNIX timestamps to the canonical ISO 8601 format used by Databento.

Functions

fmt_px
Converts a fixed-precision price to a decimal string with all 9 decimal places printed. Use Px to customize the number of printed decimal places, alignment, fill, and other formatting options.
fmt_ts
Converts a nanosecond UNIX timestamp to a human-readable string in the format [year]-[month]-[day]T[hour]:[minute]:[second].[subsecond digits:9]Z.
px_to_f64
Converts a fixed-precision price to a floating point.