fmt_enum_method

Function fmt_enum_method 

pub fn fmt_enum_method<E, F>(
    f: &mut String,
    field_name: &str,
    getter: F,
) -> Result
where E: WritePyRepr, F: FnOnce() -> Result<E>,
Available on crate feature python only.
Format an enum value obtained via a method call.

Errors

This function returns an error if it fails to expand the buffer to fit the string.