Cmbp1Msg

Struct Cmbp1Msg 

pub struct Cmbp1Msg {
    pub hd: RecordHeader,
    pub price: i64,
    pub size: u32,
    pub action: c_char,
    pub side: c_char,
    pub flags: FlagSet,
    pub ts_recv: u64,
    pub ts_in_delta: i32,
    pub levels: [ConsolidatedBidAskPair; 1],
    /* private fields */
}
Consolidated market-by-price implementation with a known book depth of 1. The record of the Cmbp1 schema.

Fields

hd: RecordHeader

The common header.

price: i64

The order price where every 1 unit corresponds to 1e-9, i.e. 1/1,000,000,000 or 0.000000001.

See Prices.

size: u32

The order quantity.

action: c_char

The event action. Can be Add, Cancel, Modify, cleaR book, or Trade.

See Action.

side: c_char

The side that initiates the event. Can be Ask for a sell order (or sell aggressor in a trade), Bid for a buy order (or buy aggressor in a trade), or None where no side is specified.

See Side.

flags: FlagSet

A bit field indicating event end, message characteristics, and data quality. See flags for possible values.

ts_recv: u64

The capture-server-received timestamp expressed as the number of nanoseconds since the UNIX epoch.

See ts_recv.

ts_in_delta: i32

The matching-engine-sending timestamp expressed as the number of nanoseconds before ts_recv.

See ts_in_delta.

levels: [ConsolidatedBidAskPair; 1]

The top of the order book.

Implementations

Source

impl Cmbp1Msg

pub fn default_for_schema(schema: Schema) -> Self

Creates a new default Cmbp1Msg for the given schema.

Source

impl Cmbp1Msg

pub fn price_f64(&self) -> f64

Converts the order price to a floating point.

UNDEF_PRICE will be converted to NaN.

This may introduce floating-point error.
pub fn action(&self) -> Result<Action>

Parses the action into an enum.

Errors

This function returns an error if the action field does not contain a valid Action.

pub fn side(&self) -> Result<Side>

Parses the side that initiates the event into an enum.

Errors

This function returns an error if the side field does not contain a valid Side.

pub fn ts_recv(&self) -> Option<OffsetDateTime>

Parses the capture-server-received timestamp into a datetime. Returns None if ts_recv contains the sentinel for a null timestamp.

pub fn ts_in_delta(&self) -> Duration

Parses the difference between ts_recv and the matching-engine-sending timestamp into a duration.