ErrorMsg

Struct ErrorMsg 

#[repr(C)]
pub struct ErrorMsg { pub hd: RecordHeader, pub err: [c_char; 302], pub code: u8, pub is_last: u8, }
An error message from the Databento Live Subscription Gateway (LSG).

Fields

hd: RecordHeader

The common header.

err: [c_char; 302]

The error message.

code: u8

The error code. See the ErrorCode enum for possible values.

is_last: u8

Sometimes multiple errors are sent together. This field will be non-zero for the last error.

Implementations

Source

impl ErrorMsg

pub fn new( ts_event: u64, code: Option<ErrorCode>, msg: &str, is_last: bool, ) -> Self

Creates a new ErrorMsg. msg will be truncated if it’s too long.

pub fn err(&self) -> Result<&str>

Parses the error message into a &str.

Errors

This function returns an error if err contains invalid UTF-8.

pub fn code(&self) -> Result<ErrorCode>

Parses the error code into an enum.

Errors

This function returns an error if the code field does not contain a valid ErrorCode.