FlagSet

Struct FlagSet 

pub struct FlagSet { /* private fields */ }
A transparent wrapper around the bit field used in several DBN record types, namely MboMsg and record types derived from it.

Most operations support constant evaluation, e.g.

use dbn::FlagSet;

const FLAGS: FlagSet = FlagSet::empty().set_snapshot().set_last();

Implementations

Source

impl FlagSet

pub const fn empty() -> Self

Returns an empty FlagSet: one with no flags set.

pub const fn new(raw: u8) -> Self

Creates a new flag set from raw.

pub const fn clear(&mut self) -> &mut Self

Turns all flags off, i.e. to false.

pub const fn raw(&self) -> u8

Returns the raw value.

pub const fn set_raw(&mut self, raw: u8)

Sets the flags directly with a raw u8.

pub const fn any(&self) -> bool

Returns true if any of the flags are on or set to true.

pub const fn is_empty(&self) -> bool

Returns true if all flags are unset/false.

pub const fn is_last(&self) -> bool

Returns true if it’s the last record in the event from the venue for a given instrument_id.

pub const fn set_last(&mut self) -> Self

Sets the LAST bit flag to true to indicate this is the last record in the event for a given instrument.

pub const fn is_tob(&self) -> bool

Returns true if it’s a top-of-book record, not an individual order.

pub const fn set_tob(&mut self) -> Self

Sets the TOB bit flag to true to indicate this is a top-of-book record.

pub const fn is_snapshot(&self) -> bool

Returns true if this record was sourced from a replay, such as a snapshot server.

pub const fn set_snapshot(&mut self) -> Self

Sets the SNAPSHOT bit flag to true to indicate this record was sourced from a replay.

pub const fn is_mbp(&self) -> bool

Returns true if this record is an aggregated price level record, not an individual order.

pub const fn set_mbp(&mut self) -> Self

Sets the MBP bit flag to true to indicate this record is an aggregated price level record.

pub const fn is_bad_ts_recv(&self) -> bool

Returns true if this record has an inaccurate ts_recv value due to clock issues or packet reordering.

pub const fn set_bad_ts_recv(&mut self) -> Self

Sets the BAD_TS_RECV bit flag to true to indicate this record has an inaccurate ts_recv value.

pub const fn is_maybe_bad_book(&self) -> bool

Returns true if this record is from a channel where an unrecoverable gap was detected.

pub const fn set_maybe_bad_book(&mut self) -> Self

Sets the MAYBE_BAD_BOOK bit flag to true to indicate this record is from a channel where an unrecoverable gap was detected.

pub const fn is_publisher_specific(&self) -> bool

Returns true if this record has the publisher-specific flag set.

pub const fn set_publisher_specific(&mut self) -> Self

Sets the PUBLISHER_SPECIFIC bit flag to true.