#[repr(C)]pub struct TradeMsg {
pub hd: RecordHeader,
pub price: i64,
pub size: u32,
pub action: c_char,
pub side: c_char,
pub flags: FlagSet,
pub depth: u8,
pub ts_recv: u64,
pub ts_in_delta: i32,
pub sequence: u32,
}Expand description
Market-by-price implementation with a book depth of 0. Equivalent to MBP-0. The record of the Trades schema.
Fields
hd: RecordHeaderThe common header.
price: i64The trade price where every 1 unit corresponds to 1e-9, i.e. 1/1,000,000,000 or 0.000000001.
See Prices.
size: u32The order quantity.
action: c_charThe event action. Always Trade in the trades schema.
See Action.
side: c_charThe side that initiates the trade. Can be Ask for a sell aggressor in a trade, Bid for a buy aggressor in a trade, or None where no side is specified.
See Side.
flags: FlagSetA bit field indicating event end, message characteristics, and data quality.
See flags for possible values.
depth: u8The book level where the update event occurred.
ts_recv: u64The capture-server-received timestamp expressed as the number of nanoseconds since the UNIX epoch.
See ts_recv.
ts_in_delta: i32The matching-engine-sending timestamp expressed as the number of nanoseconds before
ts_recv.
See ts_in_delta.
sequence: u32The message sequence number assigned at the venue.
Implementations
Sourceimpl TradeMsg
impl TradeMsg
Sourcepub fn price_f64(&self) -> f64
pub fn price_f64(&self) -> f64
Converts the price to a floating point.
UNDEF_PRICE will be converted to NaN.
Sourcepub fn ts_recv(&self) -> Option<OffsetDateTime>
pub fn ts_recv(&self) -> Option<OffsetDateTime>
Parses the capture-server-received timestamp into a datetime.
Returns None if ts_recv contains the sentinel for a null timestamp.
Sourcepub fn ts_in_delta(&self) -> Duration
pub fn ts_in_delta(&self) -> Duration
Parses the difference between ts_recv and the matching-engine-sending timestamp into a duration.