#[repr(C)]pub struct WithTsOut<T: HasRType> {
pub rec: T,
pub ts_out: u64,
}Expand description
Wrapper object for records that include the live gateway send timestamp (ts_out).
Fields
rec: TThe inner record.
ts_out: u64The live gateway send timestamp expressed as the number of nanoseconds since the UNIX epoch.
See ts_out.
Implementations
Sourceimpl<T: HasRType> WithTsOut<T>
impl<T: HasRType> WithTsOut<T>
Sourcepub fn new(rec: T, ts_out: u64) -> Self
pub fn new(rec: T, ts_out: u64) -> Self
Creates a new record with ts_out. Updates the length property in
RecordHeader to ensure the additional field is accounted for.
Sourcepub fn ts_out(&self) -> OffsetDateTime
pub fn ts_out(&self) -> OffsetDateTime
Parses the raw live gateway send timestamp into a datetime.