Cbbo1MMsg

Type Alias Cbbo1MMsg 

pub type Cbbo1MMsg = CbboMsg;
The record of the Cbbo1M schema.

Aliased Type

pub struct Cbbo1MMsg {
    pub hd: RecordHeader,
    pub price: i64,
    pub size: u32,
    pub side: i8,
    pub flags: FlagSet,
    pub ts_recv: u64,
    pub levels: [ConsolidatedBidAskPair; 1],
    /* private fields */
}

Fields

hd: RecordHeader

The common header.

price: i64

The last trade price price where every 1 unit corresponds to 1e-9, i.e. 1/1,000,000,000 or 0.000000001. Will be UNDEF_PRICE if there was no last trade in the session.

See Prices.

size: u32

The quantity of the last trade.

side: i8

The side that initiated the last trade. Can be Ask for a sell order (or sell aggressor in a trade), Bid for a buy order (or buy aggressor in a trade), or None where no side is specified.

See Side.

flags: FlagSet

A bit field indicating event end, message characteristics, and data quality. See flags for possible values.

ts_recv: u64

The end timestamp of the interval capture-server-received timestamp expressed as the number of nanoseconds since the UNIX epoch.

See ts_recv.

levels: [ConsolidatedBidAskPair; 1]

The top of the order book.