TbboMsg

Type Alias TbboMsg 

pub type TbboMsg = Mbp1Msg;
The record of the Tbbo schema.

Aliased Type

#[repr(C)]
pub struct TbboMsg { pub hd: RecordHeader, pub price: i64, pub size: u32, pub action: i8, pub side: i8, pub flags: FlagSet, pub depth: u8, pub ts_recv: u64, pub ts_in_delta: i32, pub sequence: u32, pub levels: [BidAskPair; 1], }

Fields

hd: RecordHeader

The common header.

price: i64

The order price where every 1 unit corresponds to 1e-9, i.e. 1/1,000,000,000 or 0.000000001.

See Prices.

size: u32

The order quantity.

action: i8

The event action. Can be Add, Cancel, Modify, cleaR book, or Trade.

See Action.

side: i8

The side that initiates the event. Can be Ask for a sell order (or sell aggressor in a trade), Bid for a buy order (or buy aggressor in a trade), or None where no side is specified.

See Side.

flags: FlagSet

A bit field indicating event end, message characteristics, and data quality. See flags for possible values.

depth: u8

The book level where the update event occurred.

ts_recv: u64

The capture-server-received timestamp expressed as the number of nanoseconds since the UNIX epoch.

See ts_recv.

ts_in_delta: i32

The matching-engine-sending timestamp expressed as the number of nanoseconds before ts_recv.

See ts_in_delta.

sequence: u32

The message sequence number assigned at the venue.

levels: [BidAskPair; 1]

The top of the order book.