pub struct MergeDecoder<D> { /* private fields */ }Expand description
Merges the DBN decoding streams from one or more other decoders. Both metadata and the record streams are merged.
Implementations
Sourceimpl<D> Decoder<D>where
D: DbnMetadata + DecodeRecordRef,
impl<D> Decoder<D>where
D: DbnMetadata + DecodeRecordRef,
Sourcepub fn new(decoders: Vec<D>) -> Result<Self>
pub fn new(decoders: Vec<D>) -> Result<Self>
Creates a new merge decoder from the given decoders. Both the DBN metadata and
the records will be merged.
Errors
This function returns an error if decoders is empty. Errors can also result from
failing to merge the DBN metadata. It will also return an error if one of the
inner decoders returns an error while decoding the first record. A decoder
returning Ok(None) does not result in a failure.