pub fn fmt_enum_method<E, F>(
f: &mut String,
field_name: &str,
getter: F,
) -> ResultAvailable on crate feature
python only.Expand description
Format an enum value obtained via a method call.
Errors
This function returns an error if it fails to expand the buffer to fit the string.