pub struct BboMsg {
pub hd: RecordHeader,
pub price: i64,
pub size: u32,
pub side: c_char,
pub flags: FlagSet,
pub ts_recv: u64,
pub sequence: u32,
pub levels: [BidAskPair; 1],
/* private fields */
}Expand description
Fields
hd: RecordHeaderThe common header.
price: i64The last trade price price where every 1 unit corresponds to 1e-9, i.e. 1/1,000,000,000
or 0.000000001. Will be UNDEF_PRICE if there was no last trade
in the session.
See Prices.
size: u32The quantity of the last trade.
side: c_charThe side that initiated the last trade. Can be Ask for a sell order (or sell aggressor in a trade), Bid for a buy order (or buy aggressor in a trade), or None where no side is specified.
See Side.
flags: FlagSetA bit field indicating event end, message characteristics, and data quality.
See flags for possible values.
ts_recv: u64The end timestamp of the interval capture-server-received timestamp expressed as the number of nanoseconds since the UNIX epoch.
See ts_recv.
sequence: u32The message sequence number assigned at the venue of the last update.
levels: [BidAskPair; 1]The top of the order book.
Implementations
Sourceimpl BboMsg
impl BboMsg
Sourcepub fn default_for_schema(schema: Schema) -> Self
pub fn default_for_schema(schema: Schema) -> Self
Creates a new default BboMsg for the given schema.
Sourceimpl BboMsg
impl BboMsg
Sourcepub fn price_f64(&self) -> f64
pub fn price_f64(&self) -> f64
Converts the last trade price to a floating point.
UNDEF_PRICE will be converted to NaN.
Sourcepub fn ts_recv(&self) -> Option<OffsetDateTime>
pub fn ts_recv(&self) -> Option<OffsetDateTime>
Parses the end timestamp of the interval capture-server-received timestamp into a datetime.
Returns None if ts_recv contains the sentinel for a null timestamp.