pub struct StatusMsg {
pub hd: RecordHeader,
pub ts_recv: u64,
pub action: u16,
pub reason: u16,
pub trading_event: u16,
pub is_trading: c_char,
pub is_quoting: c_char,
pub is_short_sell_restricted: c_char,
/* private fields */
}Expand description
A trading status update message. The record of the Status schema.
Fields
hd: RecordHeaderThe common header.
ts_recv: u64The capture-server-received timestamp expressed as the number of nanoseconds since the UNIX epoch.
See ts_recv.
action: u16The type of status change.
reason: u16Additional details about the cause of the status change.
trading_event: u16Further information about the status change and its effect on trading.
is_trading: c_charThe best-efforts state of trading in the instrument, either Y, N or ~.
is_quoting: c_charThe best-efforts state of quoting in the instrument, either Y, N or ~.
is_short_sell_restricted: c_charThe best-efforts state of short sell restrictions for the instrument (if applicable), either Y, N or ~.
Implementations
Sourceimpl StatusMsg
impl StatusMsg
Sourcepub fn ts_recv(&self) -> Option<OffsetDateTime>
pub fn ts_recv(&self) -> Option<OffsetDateTime>
Parses the capture-server-received timestamp into a datetime.
Returns None if ts_recv contains the sentinel for a null timestamp.
Sourcepub fn action(&self) -> Result<StatusAction>
pub fn action(&self) -> Result<StatusAction>
Parses the action into an enum.
Errors
This function returns an error if the action field does not
contain a valid StatusAction.
Sourcepub fn reason(&self) -> Result<StatusReason>
pub fn reason(&self) -> Result<StatusReason>
Parses the reason into an enum.
Errors
This function returns an error if the reason field does not
contain a valid StatusReason.
Sourcepub fn trading_event(&self) -> Result<TradingEvent>
pub fn trading_event(&self) -> Result<TradingEvent>
Parses the trading event into an enum.
Errors
This function returns an error if the trading_event field does not
contain a valid TradingEvent.
Sourcepub fn is_trading(&self) -> Option<bool>
pub fn is_trading(&self) -> Option<bool>
Parses the trading state into an Option<bool> where None indicates
a value is not applicable or available.
Sourcepub fn is_quoting(&self) -> Option<bool>
pub fn is_quoting(&self) -> Option<bool>
Parses the quoting state into an Option<bool> where None indicates
a value is not applicable or available.
Sourcepub fn is_short_sell_restricted(&self) -> Option<bool>
pub fn is_short_sell_restricted(&self) -> Option<bool>
Parses the short selling state into an Option<bool> where None indicates
a value is not applicable or available.