SystemMsg

Struct SystemMsg 

#[repr(C)]
pub struct SystemMsg { pub hd: RecordHeader, pub msg: [c_char; 303], pub code: u8, }
A non-error message from the Databento Live Subscription Gateway (LSG). Also used for heartbeating.

Fields

hd: RecordHeader

The common header.

msg: [c_char; 303]

The message from the Databento gateway.

code: u8

Type of system message. See the SystemCode enum for possible values.

Implementations

Source

impl SystemMsg

pub fn new(ts_event: u64, code: Option<SystemCode>, msg: &str) -> Result<Self>

Creates a new SystemMsg.

Errors

This function returns an error if msg is too long.

pub fn heartbeat(ts_event: u64) -> Self

Creates a new heartbeat SystemMsg.

pub fn is_heartbeat(&self) -> bool

Checks whether the message is a heartbeat from the gateway.

pub fn msg(&self) -> Result<&str>

Parses the message from the Databento gateway into a &str.

Errors

This function returns an error if msg contains invalid UTF-8.

pub fn code(&self) -> Result<SystemCode>

Parses the type of system message into an enum.

Errors

This function returns an error if the code field does not contain a valid SystemCode.