#[repr(C)]pub struct SystemMsg {
pub hd: RecordHeader,
pub msg: [c_char; 303],
pub code: u8,
}Expand description
A non-error message from the Databento Live Subscription Gateway (LSG). Also used for heartbeating.
Fields
hd: RecordHeaderThe common header.
msg: [c_char; 303]The message from the Databento gateway.
code: u8Type of system message. See the SystemCode enum
for possible values.
Implementations
Sourceimpl SystemMsg
impl SystemMsg
Sourcepub fn is_heartbeat(&self) -> bool
pub fn is_heartbeat(&self) -> bool
Checks whether the message is a heartbeat from the gateway.
Sourcepub fn msg(&self) -> Result<&str>
pub fn msg(&self) -> Result<&str>
Parses the message from the Databento gateway into a &str.
Errors
This function returns an error if msg contains invalid UTF-8.
Sourcepub fn code(&self) -> Result<SystemCode>
pub fn code(&self) -> Result<SystemCode>
Parses the type of system message into an enum.
Errors
This function returns an error if the code field does not
contain a valid SystemCode.